==> enterprisemodules-db2_config-0.1.0.tar.gz: enterprisemodules-db2_config-0.1.0/lib/puppet/type/db2_user.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_user) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access

  desc <<-DESC
  This resource allows you to manage a DB2 user. Here is an example on how to use this:

      db2_user { 'db2inst1/MYDB/MYUSER':
        ensure   => 'present',
        grants   => ['DBADM', 'SECADM', 'DATAACCESS', 'ACCESSCTRL'],
        roles    => ['SYSTS_ADM', 'SYSTS_MGR', 'SYSDEBUG', 'SYSDEBUGPRIVATE'],
      }

  This will ensure a DB2 user named `MYUSER` in database `MYDB` on instance `db2inst1`. This type is mainly available
  to manage grants and roles. It will not create the os user's needed fro this.
  DESC

  to_get_raw_resources do
    users = []
    db2_instance_names.each do |instance|
      databases_names_on(instance).each do |database|
        users += users_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    users
  end

  ensurable

  on_create do
    db2 "grant #{grants.join(',')} on database to user #{user_name}", :instance => instance_name, :database => database_name
    nil
  end

  on_modify do
    # The properties take care of this
  end

  on_destroy do
    db2 "revoke #{provider.grants.join(',')} on database from user #{user_name}", :instance => instance_name, :database => database_name
    nil
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :user_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :user_name

  property  :grants
  property  :granted
  property  :revoked
  property  :roles
end

==> enterprisemodules-db2_config-0.3.0.tar.gz: enterprisemodules-db2_config-0.3.0/lib/puppet/type/db2_user.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_user) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access

  desc <<-DESC
  This resource allows you to manage a DB2 user. Here is an example on how to use this:

      db2_user { 'db2inst1/MYDB/MYUSER':
        ensure   => 'present',
        grants   => ['DBADM', 'SECADM', 'DATAACCESS', 'ACCESSCTRL'],
        roles    => ['SYSTS_ADM', 'SYSTS_MGR', 'SYSDEBUG', 'SYSDEBUGPRIVATE'],
      }

  This will ensure a DB2 user named `MYUSER` in database `MYDB` on instance `db2inst1`. This type is mainly available
  to manage grants and roles. It will not create the os user's needed fro this.
  DESC

  to_get_raw_resources do
    users = []
    db2_instance_names.each do |instance|
      primary_database_names_on(instance).each do |database|
        users += users_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    users
  end

  ensurable

  on_create do
    db2 "grant #{grants.join(',')} on database to user #{user_name}", :instance => instance_name, :database => database_name
    nil
  end

  on_modify do
    # The properties take care of this
  end

  on_destroy do
    db2 "revoke #{provider.grants.join(',')} on database from user #{user_name}", :instance => instance_name, :database => database_name
    nil
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :user_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :user_name

  property  :grants
  property  :granted
  property  :revoked
  property  :roles
end
